@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: base_cap.cxx,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
+/* $Id: base_cap.cxx,v 1.9 2001/09/06 10:26:29 leo Exp $ */
 #include "base_cap.h"
 #include "ftpfs.h"
 #include "ftpcfg.h"
@@ -94,7 +94,6 @@ int    BaseCaptain::setcur(FList ** cr, int dd)
   return 0;
 }
 
-
 //--------------------------------------------------------------------------
 // Read directory listing using current *vfs
 // If vfs now in background mode then pop up previous one
@@ -105,6 +104,14 @@ int    BaseCaptain::direc(char *dir_ch)
   compare = comp;
   int    ret,coun;
   sort_order=rev_order ^ 1;
+  
+  xncdprintf(("BaseCap direc with vfs died bit %d\n",vfs->options & VFSDIED_BIT)); 
+  if(vfs->options & VFSDIED_BIT)
+  {
+      vfs=pop_vfs();
+      vfs->ch_curdir();
+  }
+
   ret = vfs->direc(dir_ch);
   if (ret)
   {
@@ -158,6 +165,8 @@ int    BaseCaptain::direc(char *dir_ch)
 //--------------------------------------------------------------------------
 void   BaseCaptain::selected(FList * fo)
 {
+  if(strcmp(fo->name,"..")==0)
+    return;
   fo->options ^= S_SELECT;
   if (fo->options & S_SELECT)
   {
@@ -199,6 +208,70 @@ void   BaseCaptain::setattrs(int scf,int atrib)
   vfs->ch_curdir();
 }
 
+
+//--------------------------------------------------------------------------
+//Parse given string, detect vfs type and break down path+file to parts
+//--------------------------------------------------------------------------
+struct VFS_Type_Name
+{
+  int  vfs_type;
+  char vfs_name[16];
+};
+
+const VFS_Type_Name vfs_names[]=
+{
+  { FTP_TYPE, "ftp://" },
+  { FTP_TYPE, "FTP:" },
+  { FTP_TYPE, "file:/#ftp:" },
+  { AFS_TYPE, "tar:" },
+  { DFS_TYPE, "file:" }
+};
+
+const int max_vfs_names=5;
+
+VFS_Info* BaseCaptain::get_vfs_info_for_file(char* fbuf)
+{
+  char copybuf[L_MAXPATH];
+  char *s,*s1=copybuf;
+  int i;
+  VFS_Info* vfsi=new VFS_Info;
+  strncpy(copybuf,fbuf,L_MAXPATH);
+  //First of all check for GMC #utar and others
+  if((s=strstr(copybuf,"#u"))!=0)
+  {
+    vfsi->vfstype=AFS_TYPE;
+    *s=0;
+    strcpy(vfsi->full_path,s1+5); //skipping 'file:' prefix
+    s++;
+    while(*s!='/' && *s!=0) s++;
+    get_last_and_rest_content(s,vfsi->filename,vfsi->full_path+strlen(vfsi->full_path));
+  } else
+  {
+
+    for(i=0;i<max_vfs_names;i++)
+    {
+      if(strncmp(vfs_names[i].vfs_name,fbuf,
+		 strlen(vfs_names[i].vfs_name))==0)
+	break;
+    }
+    if(i>=max_vfs_names) //Can't find any type so set to VFS_TYPE
+    {
+      vfsi->vfstype=VFS_TYPE;
+      get_last_and_rest_content(fbuf,vfsi->filename,vfsi->full_path);
+    } else
+    {
+      vfsi->vfstype=vfs_names[i].vfs_type;
+      get_last_and_rest_content(fbuf+strlen(vfs_names[i].vfs_name),
+				vfsi->filename,vfsi->full_path);    
+    }
+  }
+  xncdprintf(("vfsi: [%d][%s]->[%s]\n",
+	      vfsi->vfstype,
+	      vfsi->full_path,
+	      vfsi->filename));
+  return vfsi;
+}
+
 //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 //                            VFS stack operations
 //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@ -292,7 +365,7 @@ VFS*   BaseCaptain::pop_vfs()
 //--------------------------------------------------------------------------
 void BaseCaptain::switch_to_prev_vfs()
 {
-  vfs->delete_vfs_list();
+  delete_vfs_list();
   vfs=pop_vfs();
   // *INDENT-OFF*        
   ::chdir(curdir);
@@ -309,13 +382,66 @@ void BaseCaptain::switch_to_prev_vfs()
   showdir();
 }
 
+//--------------------------------------------------------------------------
+// Pushing current vfs, then switch to given
+// If we switching to DFS, then don't push prev vfs -> clean all stack.
+//--------------------------------------------------------------------------
+void   BaseCaptain::push_n_switch(int vfs_type, char *dir)
+{
+  char realdir[L_MAXPATH],realfile[L_MAXPATH],rest[L_MAXPATH];
+  char  *name, *b;
+  delete_vfs_list();
+  switch (vfs_type)
+  {
+  case DFS_TYPE:
+    while (vfstack != NULL)
+      pop_vfs();
+    vfs = &dfs;
+    vfs->init_support(0);
+    reset_cur();
+    strcpy(curdir, dir);
+    vfs->chdir(curdir);
+    senddir(curdir);
+    reread();
+    expose_panel();
+    break;
+  case AFS_TYPE:
+    push_vfs(vfs);
+    reset_cur();
+    vfs = &afs;
+    break_to_real_dirfile(dir,realdir, realfile, rest);
+    xncdprintf(("[%s] broken to [%s][%s][%s]\n",dir,realdir,realfile,rest));
+    ::chdir(realdir);
+    // *INDENT-ON*        
+    if (afs.init_support(realfile,rest) == 0)        //If error we return to prev VFS
+    {
+      show_vfs_error();
+      vfs = pop_vfs();
+    }
+    // *INDENT-OFF*        
+    ::chdir(curdir);
+    // *INDENT-ON*        
+    vfs->ch_curdir();
+    direc(".");
+    expose_panel();
+    break;
+  case FTP_TYPE:
+    push_vfs(vfs);
+    if(ftprec.init(dir))
+      do_ftp_link();
+    else
+      do_simple_dialog("Enter your password",FFTPCONPWD,0);
+    break;
+  };
+}
+
 //--------------------------------------------------------------------------
 // Pop up vfses from stack, cleanup all stack, then switch
 //--------------------------------------------------------------------------
 void   BaseCaptain::switch_to_vfs(int vfs_type, char *dir)
 {
   char  *name, *b;
-  vfs->delete_vfs_list();
+  delete_vfs_list();
   if (vfs->fstype != DFS_TYPE)
     while (vfstack != NULL)
       pop_vfs();
@@ -333,7 +459,7 @@ void   BaseCaptain::switch_to_vfs(int vfs_type, char *dir)
     expose_panel();
     break;
   case AFS_TYPE:
-    vfs->delete_vfs_list();
+    delete_vfs_list();
     reset_cur();
     push_vfs(vfs);
     vfs = &afs;
@@ -359,27 +485,41 @@ void   BaseCaptain::switch_to_vfs(int vfs_type, char *dir)
     direc(".");
     expose_panel();
     break;
+  case FTP_TYPE:
+    if(ftprec.init(dir))
+      do_ftp_link();
+    else
+      do_simple_dialog("Enter your password",FFTPCONPWD,0);
+    break;
   };
 }
 
 //--------------------------------------------------------------------------
 //Push current VFS then switch to given FTP with its init.
 //--------------------------------------------------------------------------
-VFS* BaseCaptain::push_n_pop(FTP *p)
+VFS* BaseCaptain::push_n_pop(VFS *p)
 {
-  vfs->delete_vfs_list();
+  delete_vfs_list();
   push_vfs(vfs);
-  vfs = &ftp;
-  ftp=*p;
-  ftp.init_internals();
-  vfs->ch_curdir();
-  if (direc(curdir) == 0)
+  switch(p->fstype)
   {
-    vfs_error("FTP", "Can't change to dir");
-    show_vfs_error();
-    vfs->chdir("..");
-    vfs->getcwd(curdir, 1020);
-    direc(curdir);
+  case FTP_TYPE:
+    vfs = &ftp;
+    ftp=*(FTP*)p;
+    ftp.init_internals();
+    vfs->ch_curdir();
+    if (direc(curdir) == 0)
+    {
+      vfs_error("FTP", "Can't change to dir");
+      show_vfs_error();
+      vfs->chdir("..");
+      vfs->getcwd(curdir, 1020);
+      direc(curdir);
+    }
+    break;
+  default:
+    xncdprintf(("WARNING: push_n_pop unsupported VFS type!!!"));
+    vfs=pop_vfs();
   }
   total_reread();
   return vfs;
@@ -430,6 +570,18 @@ void BaseCaptain::pop_and_show()
   showdir();
 }
 
+//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+
+//Cleaning directory listing
+void BaseCaptain::delete_vfs_list()
+{
+  vfs->delete_vfs_list();
+  dl.next=fl.next=0;
+  lar=0;
+  larmax=0;
+}
+
+
 //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 // Sorting functions
 //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@ -578,6 +730,22 @@ void   BaseCaptain::restore_select()
   xncdprintf(("...done\n"));
 }
 
+
+//--------------------------------------------------------------------------
+// Clean selections of current listing
+//--------------------------------------------------------------------------
+void   BaseCaptain::clean_selection()
+{
+  FList *o=dl.next;
+  int coun=0;
+  selsize = selfiles = 0;
+  while(o)
+  {
+    o->options&= ~S_SELECT;
+    o=o->next;
+  }
+}
+
 //--------------------------------------------------------------------------
 // Find item in list by filename, sets it to current
 //--------------------------------------------------------------------------
@@ -1201,6 +1369,7 @@ void   BaseCaptain::try_reread_dir()
   time_t tt;
   if (disable_reread == 0)
   {
+    xncdprintf(("Basecap try to reread dir with scan %d\n",scanfl));
     if (scanfl)
     {
       if (vfs->ch_curdir() == -1)
@@ -1627,7 +1796,7 @@ void   BaseCaptain::setattr()
 //--------------------------------------------------------------------------
 void   BaseCaptain::do_ftp_link()
 {
-  vfs->delete_vfs_list();
+  delete_vfs_list();
   push_vfs(vfs);
   vfs = &ftp;
   if (ftp.init_support((char*)&ftprec) == 0)        //If error we return to panels DFS
@@ -1652,6 +1821,14 @@ void   BaseCaptain::do_ftp_link()
     direc(curdir);
   }
   showdir();
+  masks|=PANEL_CD_DONE;
+}
+
+
+void   BaseCaptain::do_ftp_link_passwd(char *passwd)
+{
+  strcpy(ftprec.ftppasswd,passwd);
+  do_ftp_link();
 }
 
 //******************************** Virtual Methods ***********************************
@@ -1675,6 +1852,7 @@ BaseVirtual(void,showitem(FList*,int))
 BaseVirtual(void,showempty(int))
 BaseVirtual(void,show_ff_item(int,int))
 BaseVirtual(void,show_string_info(char*))
+BaseVirtual(void,do_simple_dialog(char*,ManFuncs,int))
 
 rBaseVirtual(int,am_i_visible(),0)
 rBaseVirtual(int,is_panel_vfs(VFS*),0)
