@@ -1,4 +1,4 @@
-/* $Id: base_cap.h,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
+/* $Id: base_cap.h,v 1.9 2001/09/05 13:28:07 leo Exp $ */
 #ifndef BASECAP_H // -*- c++ -*-
 #define BASECAP_H
 
@@ -74,7 +74,7 @@ class BaseCaptain
       masks=0;
     }
 
-  // Functions for working with data structures, don't make any call for visualization of ata
+  // Functions for working with data structures, don't make any call for visualization of data
   void upperpath();
   void addpathcontent(char*);
   int  findentry(char*);
@@ -83,15 +83,18 @@ class BaseCaptain
   void reset_cur() { lcurn=curn=-1;cur=base=0;};
   void reverse_sort() {rev_order^=1;};
   void restore_select();
+  void clean_selection();
   void save_select();
   void selected(FList*);
   void setattrs(int,int);
   void set_by_name(char*);
   int  is_filtered(char *s,char *ff);
   void step_to_name(char *name);
+  void set_cd_done()  { masks|=PANEL_CD_DONE; };
 
   void push_vfs(VFS*);
   VFS* pop_vfs();
+  void delete_vfs_list();
 
   void sortbyext();
   void sortbysize();
@@ -99,12 +102,15 @@ class BaseCaptain
   void sortbyname();
   void sortbyunsort();
 
+  VFS_Info* get_vfs_info_for_file(char* fbuf);
+
   // Functions that make some data transformations and call virtual methods for visualization 
   void reread();
   void switch_to_prev_vfs();
   void switch_to_vfs(int vfs_type,char *dir);
-  VFS* push_n_pop(FTP*);
+  VFS* push_n_pop(VFS*);
   void pop_and_show();
+  void push_n_switch(int vfs_type, char *dir);
   void check_and_pop(VFS *vf);
   void change_dir(char*);
   void select_by_mask(int);
@@ -129,6 +135,7 @@ class BaseCaptain
   void compare_panels();
   void setattr();
   void do_ftp_link();
+  void do_ftp_link_passwd(char *passwd);
 
 
   // Virtual functions for representing files info to user
@@ -157,7 +164,7 @@ class BaseCaptain
   virtual void show_string_info(char*);    // Show given string in status bar
   virtual void showfilelist();             // Show all file list
   virtual void clear_ff();                 // Clear fast file info
-
+  virtual void do_simple_dialog(char*, ManFuncs, int show_text=1);
 };
 
 
@@ -177,3 +184,5 @@ extern int    compare_by_size, compare_by_time;
 
 
 
+/* ------------ End of file -------------- */
+
