@@ -36,6 +36,7 @@
 #include "internals.h"
 #include "xnimlib.h"
 #include "pluginman.h"
+#include "xshrloader.h"
 
 #include <X11/cursorfont.h>
 
@@ -242,25 +243,26 @@ VFS   *BookMark::get_vfs_by_coord(int iy)
 
 void   BookMark::free_pix()
 {
-   int i;
-   for(i=0;i<max_anims;i++)
-       if(flagpix[i]!=0)
-       {
-               XFreePixmap(disp,flagpix[i]);
-               flagpix[i]=0;
-       }
-   for(i=0;i<4;i++)
-       if(pixrecycle[i]!=0)
-       {
-               XFreePixmap(disp,pixrecycle[i]);
-               pixrecycle[i]=0;
-       }
+  int i;
+  for(i=0;i<max_anims;i++)
+    if(flagpix[i]!=0)
+    {
+      default_loader->free_pixmap(flagpix[i]);
+      flagpix[i]=0;
+    }
+  for(i=0;i<4;i++)
+    if(pixrecycle[i]!=0)
+    {
+      default_loader->free_pixmap(pixrecycle[i]);
+      pixrecycle[i]=0;
+    }
 }
              
 
 int   BookMark::load_pixmap(int idx)
 {
   int    r_l, r_h;
+  char   tmp[128];
 
   if(vclass==PseudoColor)
     return 0;
@@ -275,14 +277,17 @@ int   BookMark::load_pixmap(int idx)
     case 5:
     case 6:
 
-      flagpix[idx] = LoadPixmapFromMem(flags_chr[idx], F_GIF, flagl, flagh,
-                                       CMP_AUTO,flags_sizes[idx]);
+      sprintf(tmp, "xnci_flag%d", idx + 1);
+      flagpix[idx] = default_loader->load_pixmap(ResId(tmp,flags_chr[idx],flags_sizes[idx]),
+						 flagl,flagh);
       return 1;
 
     case 7:
-      pixrecycle[0] = recyclepix = LoadPixmapFromMem(recycle_chr, F_GIF, r_l,
-                                                     r_h,CMP_AUTO,
-                                                     recycle_chr_size);
+      pixrecycle[0] = recyclepix = default_loader->load_pixmap(
+							       ResId("xnci_recycle",
+								     recycle_chr,
+								     recycle_chr_size),
+							       r_l,r_h);
       l_recycle[0] = recycle_l = (unsigned)r_l;
       h_recycle[0] = recycle_h = (unsigned)r_h;
       recyclemask = maskrecycle[0] = XCreateBitmapFromData(disp, Main, (char *)
@@ -292,8 +297,10 @@ int   BookMark::load_pixmap(int idx)
       return 1;
 
     case 8:
-      pixrecycle[1] = LoadPixmapFromMem(recycle2_chr, F_GIF, r_l, r_h,CMP_AUTO,
-                                        recycle2_chr_size);
+      pixrecycle[1] = default_loader->load_pixmap(ResId("xnci_recycle2",
+							recycle2_chr,
+							recycle2_chr_size),
+						  r_l,r_h);
       l_recycle[1] = (unsigned)r_l;
       h_recycle[1] = (unsigned)r_h;
       maskrecycle[1] = XCreateBitmapFromData(disp, Main, (char *)rec2m_bits, 
@@ -301,8 +308,10 @@ int   BookMark::load_pixmap(int idx)
       return 1;
 
     case 9:
-      pixrecycle[2] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
-                                        recycle3_chr_size);
+      pixrecycle[2] = default_loader->load_pixmap(ResId("xnci_recycle3",
+							recycle3_chr,
+							recycle3_chr_size),
+						  r_l,r_h);
       l_recycle[2] = (unsigned)r_l;
       h_recycle[2] = (unsigned)r_h;
       maskrecycle[2] = XCreateBitmapFromData(disp, Main, (char *)rec3m_bits, 
@@ -310,8 +319,10 @@ int   BookMark::load_pixmap(int idx)
       return 1;
 
     case 10:
-      pixrecycle[3] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
-                                        recycle3_chr_size);
+      pixrecycle[3] = default_loader->load_pixmap(ResId("xnci_recycle4",
+							recycle3_chr,
+							recycle3_chr_size),
+						  r_l,r_h);
       l_recycle[3] = (unsigned)r_l;
       h_recycle[3] = (unsigned)r_h;
       maskrecycle[3] = XCreateBitmapFromData(disp, Main, (char *)rec4m_bits, 
@@ -326,30 +337,39 @@ int   BookMark::load_pixmap(int idx)
 
 void   BookMark::load_flags(int n)
 {
+  char tmp[128];
   int    i = 0;
   flag_anim = 1;
   max_anims = n;
   int    r_l, r_h;
   if (vclass != PseudoColor && !is_fast_load() && !is_back_load())
     {
-      pixrecycle[0] = recyclepix = LoadPixmapFromMem(recycle_chr, F_GIF, r_l,
-                                                     r_h,CMP_AUTO,
-                                                     recycle_chr_size);
+      pixrecycle[0] = recyclepix = default_loader->load_pixmap(
+							       ResId("xnci_recycle",
+								     recycle_chr,
+								     recycle_chr_size),
+							       r_l,r_h);
       l_recycle[0] = recycle_l = (unsigned)r_l;
       h_recycle[0] = recycle_h = (unsigned)r_h;
       show_dot();
-      pixrecycle[1] = LoadPixmapFromMem(recycle2_chr, F_GIF, r_l, r_h,CMP_AUTO,
-                                        recycle2_chr_size);
+      pixrecycle[1] = default_loader->load_pixmap(ResId("xnci_recycle2",
+							recycle2_chr,
+							recycle2_chr_size),
+						  r_l,r_h);
       l_recycle[1] = (unsigned)r_l;
       h_recycle[1] = (unsigned)r_h;
       show_dot();
-      pixrecycle[2] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
-                                        recycle3_chr_size);
+      pixrecycle[2] = default_loader->load_pixmap(ResId("xnci_recycle3",
+							recycle3_chr,
+							recycle3_chr_size),
+						  r_l,r_h);
       l_recycle[2] = (unsigned)r_l;
       h_recycle[2] = (unsigned)r_h;
       show_dot();
-      pixrecycle[3] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
-                                        recycle3_chr_size);
+      pixrecycle[3] = default_loader->load_pixmap(ResId("xnci_recycle4",
+							recycle3_chr,
+							recycle3_chr_size),
+						  r_l,r_h);
       l_recycle[3] = (unsigned)r_l;
       h_recycle[3] = (unsigned)r_h;
       show_dot();
@@ -408,9 +428,9 @@ void   BookMark::load_flags(int n)
   if (vclass != PseudoColor && allow_animation && !is_fast_load() && !is_back_load())
     for (i = 0; i < n; i++)
       {
-//        sprintf(tmp, "%s/flag%d.gif", syspath, i + 1);
-        flagpix[i] = LoadPixmapFromMem(flags_chr[i], F_GIF, flagl, flagh,
-                                       CMP_AUTO,flags_sizes[i]);
+        sprintf(tmp, "xnci_flag%d", i + 1);
+        flagpix[i] = default_loader->load_pixmap(ResId(tmp,flags_chr[i],flags_sizes[i]),
+						 flagl,flagh);
         if (flagpix[i] == 0)
           {
             flag_anim = 0;
@@ -666,6 +686,7 @@ int    BookMark::add_book(int n, char *s, int type)
   act_books[n] = 1;
   last_used = n;
   strcpy(fs[n], fschr[type]);
+  xncdprintf(("Bookmark adding book [%s] with type [%s]\n",s,fschr[type]));
   return 1;
 }
 
@@ -941,10 +962,7 @@ void   BookMark::swap_books(int i)
   else
     {
       strcpy(t, books[i]);
-      if (fs[i][1] == 'F')
-        typ = DFS_TYPE;
-      else if (fs[i][1] == 'R')
-        typ = AFS_TYPE;
+      typ=detect_fs(fs[i]);
       if (flag_anim && mapped)
         animate_swapping(i);
       strcpy(books[i], panel->vfs->get_info_for_bookmark());
@@ -999,10 +1017,7 @@ void   BookMark::switch_books(int i)
         }
       if (flag_anim && mapped)
         animate_moving(i);
-      if (fs[i][1] == 'F')
-        typ = DFS_TYPE;
-      else if (fs[i][1] == 'R')
-        typ = AFS_TYPE;
+      typ=detect_fs(fs[i]);
       panel->switch_to_vfs(typ, books[i]);
       if (i != last_used)
         {
