@@ -156,8 +156,7 @@ int deGIF(char* fbu,PICINFO* pinfo,int fsiz)
 {
   /* returns '1' if successful */
 
-  char *fname;
-  register byte  ch, ch1, *origptr;
+  register byte  ch, *origptr;
   register int   i, block;
   int            aspect, gotimage;
 
@@ -238,7 +237,7 @@ int deGIF(char* fbu,PICINFO* pinfo,int fsiz)
    *       or a plaintext extension
    */
 
-  while (1) {
+  while (dataptr-RawGIF<filesize) {
     block = NEXTBYTE;
 
 
@@ -349,10 +348,6 @@ int deGIF(char* fbu,PICINFO* pinfo,int fsiz)
       else if (fn == 0xF9) {  /* Graphic Control Extension */
         int j, sbsize;
 
-
-        fprintf(stderr, "%s:  %s", bname,
-                "Graphic Control Extension in GIF file.  Ignored.");
-
         /* read (and ignore) data sub-blocks */
         do {
           j = 0; sbsize = NEXTBYTE;
@@ -377,10 +372,6 @@ int deGIF(char* fbu,PICINFO* pinfo,int fsiz)
         int j, sbsize;
 
 
-        fprintf(stderr,
-                "%s:  Unknown extension 0x%02x in GIF file.  Ignored.",
-                bname, fn);
-
         /* read (and ignore) data sub-blocks */
         do {
           j = 0; sbsize = NEXTBYTE;
@@ -461,7 +452,7 @@ int leo_coun=0;
 /********************************************/
 int readImage(PICINFO* pinfo)
 {
-  register byte ch, ch1, *ptr1, *picptr;
+  register byte ch, *picptr;
   int           i, npixels, maxpixels;
 
   npixels = maxpixels = 0;
