@@ -3,10 +3,14 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include "xh.h"
+#include "globals.h"
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
 #include "picinfo.h"
 #include <math.h>
 
+extern Display* disp;
+extern Colormap         defcmp;
 extern int conv24;
 extern int vclass;
 void init_imagengine();
@@ -48,3 +52,5 @@ extern "C" void set_method(int method);
 #endif
 //////////////////////////////////////////End of file///////////////////////////////////////////
 
+/* ------------ End of file -------------- */
+
