@@ -18,7 +18,7 @@
 #define VALUES_LEN	80	/* Max length of values line */
 #define TOKEN_LEN	8	/* Max length of color token */
 
-#include "xh.h"
+#include "image.h"
 #include "picinfo.h"
 #include "accel.h"
 
