@@ -96,7 +96,7 @@ void XEVENT()
 */}
 
 int pid;
-void main(int argc,char** argv)
+int main(int argc,char** argv)
 {
  char name[40]="XnLaunch v1.0";
  fprintf(stderr,"Initialisation:\n");
@@ -126,6 +126,7 @@ void main(int argc,char** argv)
  fprintf(stderr,"OK\n");
  DeinitXClient();
  }
+ return 0;
 }
 
 Switch* guiplugin_new_Switch(int ix,int iy,int il,char *iname,ulong icol,void (*ifunc)())
