@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: main.cxx,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
+/* $Id: main.cxx,v 1.19 2001/09/13 15:02:09 leo Exp $ */
 
 #include "panel.h"
 #include "scroll.h"
@@ -35,24 +35,19 @@
 #include "internals.h"
 #include "pluginman.h"
 #include "ives/ivesclient.h"
+#include "xshrloader.h"
 
 char   ver[] = "X Northern Captain "XNCVERSION;
 
 
 extern Window main_win;
 extern Atom   wmDeleteWindow;
-extern void   init_chown_dialog(FList *);
-extern void   dfs_info(int);
-extern void   free_info(int);
 extern void   find_panel(int);
 extern int    term_sticky;
 extern int    dont_ask;        //Placed in panel.cxx
 extern int    layout;
 extern Viewer vw1;
 extern Editor ew1;
-extern void   menupanel(int (*)(int, char *));
-extern int    panexec2(int, char *);
-extern void   newtextfile(char *, Lister *, int);
 extern int    just_at_startup;
 extern int    focus_fl;
 extern char   shdir[];
@@ -446,12 +441,14 @@ void   p2brief()
 void   p1full()
 {
   lst1->brief = 0;
+  submenu1->switches(2); //Set column to one in menu.
   p1col1();
 }
 
 void   p2full()
 {
   lst2->brief = 0;
+  submenu2->switches(2); //Set column to one in menu.
   p2col1();
 }
 
@@ -635,7 +632,7 @@ void   remntfunc()
 
 void   manfunc()
 {
-  newtextfile("Man page", panel, 11);
+  newtextfile("Man page", panel, FMANPAGE);
 }
 
 void full_reconfig()
@@ -670,6 +667,9 @@ int    XEVENT(XEvent * event)
   ev = *event;
   evret = 1;
 
+  if(default_dnd_man->process_event(event))
+    return 1;
+
   if (just_at_startup == 2 && ev.xany.window == Main)
     {
       guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
@@ -786,6 +786,7 @@ int    XEVENT(XEvent * event)
             resize_done2 = 0;
           };
         };
+      default_dnd_man->update_geoms();
     };
   return evret;
 }
@@ -827,8 +828,17 @@ void   xnc_main(int argc, char **argv)
   if(rs_plugin_name)
     pluginman.load_look((char*)rs_plugin_name);
   InitXClient(argc, argv, 15, 70, 740, 455, ver);
+  default_dnd_man=new DndManager(disp,Main);
   init_imagengine();
   GuiLocale::init_locale();
+  if(is_shared_load())
+  {
+    xncdprintf(("Using shared loading\n"));
+    default_loader=new xsharedLoader(SharedRead);
+  }
+  else
+    default_loader=new xsharedLoader(NonShared);
+  default_loader->init();
   iclient=new IVES_client(ives_retval);
   if(is_show_intro() || is_new_version())
           show_intro();
@@ -876,7 +886,7 @@ void   xnc_main(int argc, char **argv)
   create_dnd_cursors();
   bmark = guiplugin->new_BookMark(35, Mainh - 63);
   bmark->set_iname("BOOKMARK");
-
+  
 }
 
 void   xnc_exit();
@@ -884,7 +894,6 @@ void   xnc_exit();
 void   xnc_sig()
 {
   signal(SIGSEGV, sig_fault);
-  qv_signal();
 }
 
 void   xnc_gofunc()
@@ -1038,6 +1047,7 @@ void   xnc_exit()
 	             "<majordomo@xnc.dubna.su> and you are inside.\n");
       fprintf(stderr, "------------------------------------------------------------------------------\n");
       fprintf(stderr, "Thank you. You have run X Northern Captain %d times!\n", xnc_starts);
+      delete default_dnd_man;
       DeinitXClient();
     }
 }
