@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: panel.cxx,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
+/* $Id: panel.cxx,v 1.19 2001/09/06 11:27:27 leo Exp $ */
 #include "panel.h"
 #include "au/key.h"
 #include "au/x_actions.h"
@@ -39,7 +39,6 @@ const int EXTCOL = 9;
 const int LINKCOL = 10;
 const int AFSCOL = 11;
 
-
 extern void try_clean_afs_cache();
 
 
@@ -324,6 +323,12 @@ void   Lister::expose()
   fl = (l - 88) / 2;
   vl = fl / fixl;
   int    dl = 0;
+  xncdprintf(("====Expose for panel %d====\n",lay));
+  if(lay>0 && panel!=this) //We are under next panel window -> don't need expose
+  {
+    xncdprintf(("==== >>  SKIPPED  << ====\n",lay));
+    return;
+  }
   if (sl > vl)
     dl = sl - vl;
   vl = sl - dl;
@@ -468,6 +473,7 @@ void   Lister::expose()
     showfinfo(cur);
   else
     disable_reread = 0;
+  xncdprintf(("====End expose for panel %d====\n",lay));
 }
 
 
@@ -648,9 +654,71 @@ void   Lister::show()
     XSetWindowBackgroundPixmap(disp, w, main_pixmap);
   XMapRaised(disp, w);
   addto_el(this, w);
+  if(default_dnd_man)
+  {
+    default_dnd_man->add_dnd_object(this,w);
+    dndwin->add_type("text/uri-list");
+  }
   //  scr->show();
 }
 
+int  Lister::dnd_drop(DndData* dd, int x, int y, Atom action)
+{
+  Lister *slavepan=panel2;
+  int i=0,mx,my;
+  FList *o;
+  char fname[L_MAXPATH];
+  if(dd->break_to_filelist())
+  {
+    Atom amove=XInternAtom(disp,"XdndActionMove",False);
+    VFS_Info* vfsi;
+    dd->show_filelist();
+    vfsi=get_vfs_info_for_file(dd->file_list[0]);
+    default_dnd_man->global2win_coords(w,x,y,mx,my);
+    o=find_entry_by_coord(mx,my);
+    if(o && strcmp(o->name,"..") && (o->mode & S_IFDIR)==S_IFDIR)
+    {
+      slavepan=panel2;
+      vfs->chdir(o->name);
+      vfs->getcwd(curdir,1020);
+      direc(curdir);
+      xncdprintf(("Drop on entry: [%s] coords %d,%d\n",o->name,mx,my));
+    }
+    else
+    {
+      if(lay!=0 && my<30)  //We are in page layout
+      {
+	int tx;
+	tx=l/2*(lay%2);
+	if(mx>=tx && mx<tx+l/2)
+	  slavepan=this;
+      }
+      xncdprintf(("Drop on whole panel\n"));
+    }
+
+    slavepan->switch_to_me();
+    slavepan->push_n_switch(vfsi->vfstype,vfsi->full_path);
+    slavepan->clean_selection();
+    for(i=0;i<dd->file_listlen;i++)
+    {
+      get_last_content(dd->file_list[i],fname);
+      xncdprintf(("file->list: [%s]\n",fname));
+      o=slavepan->find_file_entry(fname);
+      if(o)
+	slavepan->select_file(o);
+    }
+    if(action==amove)
+      slavepan->move();
+    else
+      slavepan->copy();
+    delete vfsi;
+  }
+  delete dd;
+  xncdprintf(("*********End dnd_drop**********\n"));
+  return 1;
+}
+
+
 void   draw_filled_urect(Window w, GC gcw, int x, int y, int l, int h)
 {
   /*
@@ -1089,6 +1157,32 @@ void   Lister::showdir()
 }
 
 
+//--------------------------------------------------------------------------
+//Return pointer to entry in listing by coords in panel
+//return 0 if missed
+//--------------------------------------------------------------------------
+FList* Lister::find_entry_by_coord(int x, int y)
+{
+  FList *obj;
+  int k;
+  if (y > 30 && x > 8 && y < h - 30)
+  {
+    k = (y - 30) / tdl + (x - 8) / (pl + 4) * th;
+    if (k < th * col)
+    {
+      obj=base;
+      while(obj && k)
+      {
+	k--;
+	obj=obj->next;
+      }
+      return obj;
+    }
+  }
+  return 0;
+}
+
+
 ///////////////////////////////////FS operations//////////////////////////////
 void   Lister::fserror(char *head, FList * o)
 {
@@ -1202,37 +1296,24 @@ void   Lister::remount()
 
 void   Lister::ext_exec(char *exec)
 {
-  char   findchr[8192];
+  char   findchr[2*L_MAXPATH];
   char   fname[L_MAXPATH];
   char   fdir[L_MAXPATH];
+  char   execdup[L_MAXPATH];
   char  *s, c, *b;
 
   if (vfs->is_exec_supported())
   {
     char  *name = vfs->get_file_for_execute(cur->name);
+    strcpy(execdup,exec);
     if (name == NULL)
     {
       show_vfs_error();
       return;
     }
     char  *execdir = vfs->get_execute_dir();
-    if (findsubstr(exec, "%s/%s"))
-    {
-      chdir(panel2->curdir);
-      senddir(panel2->curdir);
-      sprintf(fdir, "%s/%s", execdir, name);
-      quote_path(fname, fdir);
-      b=strchr(fname, '/');
-      *b=0;b++;
-      sprintf(findchr, exec, fname, b);
-    }
-    else
-    {
-      senddir(execdir);
-      quote_path(fname, name);
-      sprintf(findchr, exec, fname);
-    }
-    s = findchr;
+
+    s = execdup;
     while (*++s)
     {
       if (*s == '#')
@@ -1260,6 +1341,23 @@ void   Lister::ext_exec(char *exec)
 	  break;
       }
     }
+
+    if (findsubstr(execdup, "%s/%s"))
+    {
+      chdir(panel2->curdir);
+      senddir(panel2->curdir);
+      sprintf(fdir, "%s/%s", execdir, name);
+      quote_path(fname, fdir);
+      b=strchr(fname, '/');
+      *b=0;b++;
+      sprintf(findchr, execdup, fname, b);
+    }
+    else
+    {
+      senddir(execdir);
+      quote_path(fname, name);
+      sprintf(findchr, execdup, fname);
+    }
     raise_terminal_if_need();
     flush_screen();
     tt_printf("%s\n", findchr);
@@ -1274,8 +1372,9 @@ void   Lister::ext_exec(char *exec)
 
 void   Lister::menu_exec(char *mecom)
 {
-  char   findchr[255];
+  char   findchr[L_MAXPATH];
   char  *suc;
+  xncdprintf(("Menu command: [%s]\n",mecom));
   if (vfs->is_exec_supported())
   {
     char  *name = vfs->get_file_for_execute(cur->name);
@@ -1292,7 +1391,7 @@ void   Lister::menu_exec(char *mecom)
       while (*suc != ')' && *suc != 0)
 	wfile[i++] = *suc++;
       wfile[i] = 0;
-      newtextfile(wfile, this, 10);
+      newtextfile(wfile, this, FWIDEEXEC);
     }
     else
     {
@@ -1307,6 +1406,7 @@ void   Lister::menu_exec(char *mecom)
 	senddir(execdir);
 	sprintf(findchr, mecom, name);
       };
+      xncdprintf(("Executing menu command [%s]\n", findchr));
       raise_terminal_if_need();
       flush_screen();
       tt_printf("%s\n", findchr);
@@ -1526,11 +1626,11 @@ void   Lister::del()
     if(use_prompt & PROMPT_DEL)
     {
       bmark->set_recycle_image(0);
-      initquery("Delete file?", this, panel2->vfs, 0);
+      initquery("Delete file?", this, panel2->vfs, FDELETE);
     } else
     {
       set_dbuf(panel2->vfs);
-      funcs(0);
+      funcs(FDELETE);
     }
       
   }
@@ -1544,13 +1644,13 @@ void   Lister::copy()
     if(use_prompt & PROMPT_COPY)
     {
       if (selfiles)
-        init_copymove_query("Copy files?", this, panel2->vfs, 1);
+        init_copymove_query("Copy files?", this, panel2->vfs, FCOPY);
       else
-        initdialog("Copy file", this, panel2->vfs, 1);
+        initdialog("Copy file", this, panel2->vfs, FCOPY);
     } else
     {
       set_dbuf(panel2->vfs);
-      funcs(1);
+      funcs(FCOPY);
     }
   }
 }
@@ -1563,13 +1663,13 @@ void   Lister::copy(VFS * vf)
     if(use_prompt & PROMPT_COPY)
     {
       if (selfiles)
-        init_copymove_query("Copy files?", this, vf, 1);
+        init_copymove_query("Copy files?", this, vf, FCOPY);
       else
-        initdialog("Copy file", this, vf, 1);
+        initdialog("Copy file", this, vf, FCOPY);
     } else
     {
       set_dbuf(vf);
-      funcs(1);
+      funcs(FCOPY);
     }
   }
 }
@@ -1584,13 +1684,13 @@ void   Lister::move()
     if(use_prompt & PROMPT_MOVE)
     {
       if (selfiles)
-        init_copymove_query("Move files?", this, panel2->vfs, 2);
+        init_copymove_query("Move files?", this, panel2->vfs, FMOVE);
       else
-        initdialog("Move file", this, panel2->vfs, 2);
+        initdialog("Move file", this, panel2->vfs, FMOVE);
     } else
     {
       set_dbuf(panel2->vfs);
-      funcs(2);
+      funcs(FMOVE);
     }
   }
 }
@@ -1603,13 +1703,13 @@ void   Lister::move(VFS * vf)
     if(use_prompt & PROMPT_MOVE)
     {
       if (selfiles)
-        init_copymove_query("Move files?", this, vf, 2);
+        init_copymove_query("Move files?", this, vf, FMOVE);
       else
-        initdialog("Move file", this, vf, 2);
+        initdialog("Move file", this, vf, FMOVE);
     } else
     {
       set_dbuf(panel2->vfs);
-      funcs(2);
+      funcs(FMOVE);
     }
   }
 }
@@ -1914,50 +2014,54 @@ void   Lister::activate()
   delete dub;
 }
 
-void   Lister::funcs(int nn)
+
+void   Lister::funcs(ManFuncs funcnum)
 {
-  switch (nn)
+  switch (funcnum)
   {
-  case 0:
+  case FDELETE:
     fdelete();
     break;
-  case 1:
+  case FCOPY:
     fcopy();
     break;
-  case 2:
+  case FMOVE:
     fmove();
     break;
-  case 3:
+  case FMKDIR:
     fmkdir();
     break;
-  case 4:
+  case FEDIT:
     fedit();
     break;
-  case 5:
+  case FSELBYMASK:
     select_by_mask(1);
     break;
-  case 6:
+  case FDESELMASK:
     select_by_mask(0);
     break;
-  case 7:
+  case FSETATTR:
     setattr();
     break;
-  case 8:
+  case FLPR:
     lpr();
     break;
-  case 10:
+  case FWIDEEXEC:
     wide_exec();
     break;
-  case 11:
+  case FMANPAGE:
     man_page();
     break;
-  case 12:
+  case FFTPCON:
     do_ftp_link();
     break;
-  case 20:
+  case FFTPCONPWD:
+    do_ftp_link_passwd(dbuf);
+    break;
+  case FCHOWN:
     chowns();
     break;
-  case 22:
+  case FMOUNT:
     panmntmnt();
     break;
   }
@@ -2000,7 +2104,7 @@ void   Lister::send_dnd_message()
 void   Lister::mkdir()
 {
   vfs->ch_curdir();
-  newtextfile("Make directory", this, 3);
+  newtextfile("Make directory", this, FMKDIR);
 }
 
 
@@ -2027,7 +2131,7 @@ void   Lister::attrib()
 {
   // *INDENT-OFF*        
   if(selfiles==0) 
-    ::attrib(cur,7);
+    ::attrib(cur,FSETATTR);
   else 
     attrib2();
   // *INDENT-ON*        
@@ -2035,6 +2139,11 @@ void   Lister::attrib()
 
 }
 
+void   Lister::do_simple_dialog(char* head, ManFuncs fnum, int show_text)
+{
+  newtextfile(head,this,fnum,show_text);
+}
+
 void   Lister::try_to_add_to_bookmark(int cy)
 {
   char strtmp[L_MAXPATH];
@@ -2219,11 +2328,38 @@ void   Lister::create_ftp_link()
     return;
   }
   vfs->ch_curdir();
-  new_ftp_prompt(this,12);
+  new_ftp_prompt(this,FFTPCON);
   //  newtextfile("Connect to Ftp Host", this, 12);
 }
 
-
+void Lister::switch_to_me()
+{
+  panel = this;
+  focus_fl = 1;
+  XRaiseWindow(disp, w);
+  default_dnd_man->move_to_top(w);
+  xncdprintf(("Chdir to %s\n",vfs->curdir));
+  vfs->ch_curdir();
+  if (curn == -1)
+  {
+    curn = lcurn;
+    if (cur == NULL)
+      reread();
+    showitem(cur, curn);
+  }
+  if (cmdl)
+  {
+    cmdl->save_input();
+    cmdl->setpath(curdir);
+  }
+  senddir(curdir);
+  if(cmdl)
+  {
+    cmdl->restore_input();
+    cmdl->expose();
+  }
+  XFlush(disp);
+}
 
 void   Lister::click()
 {
@@ -2250,6 +2386,18 @@ void   Lister::click()
       dnd_starty = ev.xbutton.y;
       dnd_start_valid = 1;
       clear_ff();
+      //Support for mouse wheel
+      if(ev.xbutton.button == Button5)
+      {
+	right();
+	break;
+      }
+      if(ev.xbutton.button == Button4)
+      {
+	left();
+	break;
+      }
+      //
       switch (lay)
       {
       case 0:
@@ -2352,7 +2500,7 @@ void   Lister::click()
 	  // *INDENT-OFF*        
 	  else 
 	    if(selfiles==0) 
-	      ::attrib(cur,7); 
+	      ::attrib(cur,FSETATTR); 
 	    else 
 	      attrib2();
 	  // *INDENT-ON*        
@@ -2361,28 +2509,7 @@ void   Lister::click()
       break;
 
     case FocusIn:
-      panel = this;
-      focus_fl = 1;
-      XRaiseWindow(disp, w);
-      if (curn == -1)
-      {
-	vfs->ch_curdir();
-	curn = lcurn;
-	if (cur == NULL)
-	  reread();
-	showitem(cur, curn);
-      }
-      if (cmdl)
-      {
-	cmdl->save_input();
-	cmdl->setpath(curdir);
-      }
-      senddir(curdir);
-      if(cmdl)
-      {
-	cmdl->restore_input();
-	cmdl->expose();
-      }
+      switch_to_me();
       foc = 1;
       break;
     case FocusOut:
@@ -2617,10 +2744,10 @@ void   Lister::click()
 	showfilelist();
 	break;
       case ASelectMask:
-	selectmask(this, 5);
+	selectmask(this, FSELBYMASK);
 	break;
       case ADeselectMask:
-	selectmask(this, 6);
+	selectmask(this, FDESELMASK);
 	break;
       case ARemountList:
 	for (i = 0; i < mntmax; i++)
@@ -2631,7 +2758,7 @@ void   Lister::click()
 	remount();
 	break;
       case AMan:
-	newtextfile("Man page", this, 11);
+	newtextfile("Man page", this, FMANPAGE);
 	break;
       case AFDelete:
 	clear_ff();
@@ -2649,12 +2776,12 @@ void   Lister::click()
 	donefunc();
 	break;
       case APrint:
-	initquery("Print file", this, panel2->vfs, 8);
+	initquery("Print file", this, panel2->vfs, FLPR);
 	break;
       case AAttributes:
 	// *INDENT-OFF*        
 	if(selfiles==0) 
-	  ::attrib(cur,7); 
+	  ::attrib(cur,FSETATTR); 
 	else 
 	  attrib2();
 	// *INDENT-ON*        
@@ -2680,7 +2807,7 @@ void   Lister::click()
 #endif
       case AFNewEdit:
 	clear_ff();
-	newtextfile("New text file", this, 4);
+	newtextfile("New text file", this, FEDIT);
 	break;
       case AFEdit:
 	vfs->ch_curdir();
@@ -2698,7 +2825,7 @@ void   Lister::click()
 	break;
       case AMakeDir:
 	vfs->ch_curdir();
-	newtextfile("Make directory", this, 3);
+	newtextfile("Make directory", this, FMKDIR);
 	break;
       case ARereadDir:
 	lastscan = 0;
@@ -2804,3 +2931,7 @@ void   Lister::click()
   }
 }
 ////////////////////////////////End of file/////////////////////////////////////////
+
+
+
+
