@@ -12,9 +12,12 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: pluginman.cxx,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
+/* $Id: pluginman.cxx,v 1.13 2001/07/13 14:57:24 leo Exp $ */
 #include "pluginman.h"
 #include "xncdirs.h"
+
+#ifdef USE_SHARED_LOADING
+
 /////////////////////////////////////////////////////////////////////////////
 // This part of code taken from SWI_Prolog pl-load.c. Thanks to Jan Wielemaker
 		 /*******************************
@@ -70,6 +73,16 @@ dlsym(void* vhandle, const char *name)
 #endif
 
 #endif
+
+#ifdef HAVE_DLOPEN
+#ifndef __ELF__                         /* a.out systems need to prefix 
+       			        	/* an */                                                                           
+#define dlsym(x,y) dlsym(x, "_" y)      /* underscore to symbol names */        
+#endif                                                                         
+
+#endif
+
+#endif /* USE_SHARED_LOADING */
 ////////////////////////////////////////////////////////////////////////////
 
 
@@ -89,6 +102,7 @@ PluginManager::PluginManager()
 
 GuiPlugin* PluginManager::load_gui_plugin(char* plugin_name)
 {
+#ifdef USE_SHARED_LOADING
   char libname[L_MAXPATH];
   void *plugin_handle;
   const char *error;
@@ -132,6 +146,11 @@ GuiPlugin* PluginManager::load_gui_plugin(char* plugin_name)
   pobj->set_handle(plugin_handle);
   fprintf(stderr,"Plugin %s v.%s registered\n",pobj->Name(),pobj->Version());
   return pobj;
+#else
+  fprintf(stderr,"\nWARNING: Program compiled WITHOUT shared object loading "
+                 "interface\nWARNING: Plugins support is disabled\n\n");
+  return 0;
+#endif
 }
 
 int PluginManager::load_look(char* look_name)
@@ -149,6 +168,7 @@ int PluginManager::load_look(char* look_name)
 
 void PluginManager::unload_look()
 {
+#ifdef USE_SHARED_LOADING
   void* handle;
   if(guiplugin)
   {
@@ -158,6 +178,7 @@ void PluginManager::unload_look()
     delete guiplugin;
     baseguiplugin=guiplugin=0;
   }
+#endif
 }
 
 
