@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: aquagui.cxx,v 1.2 2001/04/17 11:29:53 leo Exp $ */
+/* $Id: aquagui.cxx,v 1.9 2001/09/06 11:28:09 leo Exp $ */
 #include "guiplugin.h"
 #include "aquagui.h"
 #include "scroll.h"
@@ -829,6 +829,7 @@ void   AquaMenu::expose()
   XClearWindow(disp,w);
   for (i = 0; i < max; i++)
     showitem(i);
+  XRaiseWindow(disp,w);
 }
 
 void   AquaMenu::select(int i)
@@ -2244,7 +2245,7 @@ void AquaInfoWin::expose_counter()
   if(fullcoun<=0)
     fullcoun=1;
   prect(w, gcw, 10, h-25-deltay, l-20, 10);
-  ll=(l-24)*currentcoun/fullcoun;
+  ll=int(float((l-24))*float(currentcoun)/fullcoun);
   XSetForeground(disp,gcw,keyscol[1]);
   XClearArea(disp, w, 12+ll, h-23-deltay, l-24-ll,6,False);
   XSetForeground(disp,gcw,cols[4]);
