@@ -12,11 +12,12 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: fivefuncs.cxx,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
+/* $Id: fivefuncs.cxx,v 1.8 2001/09/13 15:02:11 leo Exp $ */
 #include "fiveplugin.h"
 #include "internals.h"
 #include "image.h"
 #include "fivegui.h"
+#include "xshrloader.h"
 
 extern char fiveskin_chr[];
 extern int  fiveskin_chr_size;
@@ -24,11 +25,17 @@ extern int  fiveskin_chr_size;
 void   five_load_skins()
 {
   int x,y;
+  LoaderMode oldmode;
   fprintf(stderr,"Loading skins..");
   show_dot();
   im_populate_pallete(skincol);
   show_dot();
-  skin.skin=LoadPixmapFromMem(fiveskin_chr, F_GIF, x, y, CMP_COM, fiveskin_chr_size);
+  oldmode=default_loader->set_workmode(NonShared);
+  skin.skin=default_loader->load_pixmap(ResId("xnci_p_five_skin",
+					      fiveskin_chr,
+					      fiveskin_chr_size
+					      ),x,y);
+  default_loader->set_workmode(oldmode);
   show_dot();
   im_clear_global_pal();
   show_dot();
