@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: fivegui.cxx,v 1.1.1.1 2001/04/17 08:45:26 leo Exp $ */
+/* $Id: fivegui.cxx,v 1.11 2001/09/06 11:28:11 leo Exp $ */
 #include "guiplugin.h"
 #include "fivegui.h"
 #include "scroll.h"
@@ -848,6 +848,7 @@ void   FiveMenu::expose()
   XDrawLine(disp, w, gcw, l - 1, 0, l - 1, h);
   for (i = 0; i < max; i++)
     showitem(i);
+  XRaiseWindow(disp,w);
 }
 
 void   FiveMenu::select(int i)
@@ -1376,7 +1377,7 @@ void FiveInfoWin::expose_counter()
     fullcoun=1;
   XSetForeground(disp, gcw, SCOL8);
   XDrawRectangle(disp, w, gcw, 10, h-25-deltay, l-20, 10);
-  ll=(l-24)*currentcoun/fullcoun;
+  ll=int(float((l-24))*float(currentcoun)/fullcoun);
   XSetForeground(disp, gcw, SCOL21);
   XFillRectangle(disp, w, gcw, 12+ll, h-23-deltay, l-24-ll,6);
   XSetForeground(disp,gcw, SCOL8);
