@@ -99,7 +99,7 @@ extern void   (*xnc_setsignals)();
 extern int    (*xnc_look_for_key)(XEvent*);
 extern void   (*xnc_setdir)();
 extern void   (*xnc_work_anim)();
-extern void   (*xnc_look_at_pipes)(fd_set*);
+extern void   (*xnc_look_at_pipes)(fd_set*,int);
 extern int    (*xnc_set_pipes)(fd_set*, int);
 extern int    (*xnc_is_my_child)(int,int);
 extern void   (*xnc_run_once)();
@@ -107,6 +107,7 @@ int onlyrun=1;
 int disable_modifiers=0;
 extern Window main_win;
 
+static short    changettyowner = 1;
 
 #ifdef USE_GETGRNAME
 # include <grp.h>
@@ -508,11 +509,22 @@ static int waitret=0;
 
 static RETSIGTYPE Child_die(int unused)
 {
- child_work=0;
- wait(&waitret);
- signal(SIGCHLD,Child_signal);
+  /*  fprintf(stderr,"Child_die: got SIGCHLD signal, processing...\n"); */
+  child_work=0;
+  wait(&waitret);
+  signal(SIGCHLD,Child_signal);
 }
 
+void   m_delay(int usec)
+{
+  struct timeval time;
+  usec *= 1000;
+  time.tv_sec = usec / 1000000L;
+  time.tv_usec = usec % 1000000L;
+  select(0, (fd_set *) NULL, (fd_set *) NULL, (fd_set *) NULL, &time);
+}
+
+
 extern int disable_reread;
 int psystem2(char *str, ...)
 {
@@ -531,29 +543,31 @@ int psystem2(char *str, ...)
   }
   va_end(ap);
   signal(SIGCHLD,Child_die);
-  pid=fork();
   child_work=1;
+  pid=fork();
   if(pid==-1)
   {
-         child_work=0;
-         signal(SIGCHLD,Child_signal);
-         return 255;
+     child_work=0;
+     signal(SIGCHLD,Child_signal);
+     return 255;
   }
   if(pid==0)
   {
-          close(1);
-          close(2);
-          execvp(argv[0],argv);
-          exit(254);
+     close(1);
+     close(2);
+     execvp(argv[0],argv);
+     exit(254);
   }
   disable_reread=1;
+  /*  fprintf(stderr,"Waiting for child die....\n"); */
   while(child_work)
   {
-    if(child_work && XPending(Xdisplay))
+    if(XPending(Xdisplay))
     {
-     XNextEvent(Xdisplay,&ev);
-     process_x_event(&ev);
-    }
+      XNextEvent(Xdisplay,&ev);
+      process_x_event(&ev);
+    } else
+      m_delay(10);
   }
   disable_reread=1;
   return WEXITSTATUS(waitret);
@@ -605,6 +619,248 @@ clean_exit (void)
  * If successful, ttydev and ptydev point to the names of the
  * master and slave parts
  */
+int
+get_pty(void)
+{
+    int             fd;
+    char           *ptydev;
+
+#ifdef PTYS_ARE__GETPTY
+    if ((ptydev = ttydev = _getpty(&fd, O_RDWR | O_NDELAY, 0622, 0)) != NULL)
+	goto Found;
+#endif
+#ifdef PTYS_ARE_GETPTY
+    while ((ptydev = getpty()) != NULL)
+	if ((fd = open(ptydev, O_RDWR)) >= 0) {
+	   ttydev = ptydev;
+	   goto Found;
+	}
+#endif
+#if defined(HAVE_GRANTPT) && defined(HAVE_UNLOCKPT)
+# if defined(PTYS_ARE_GETPT) || defined(PTYS_ARE_PTMX)
+    {
+	extern char    *ptsname();
+
+#  ifdef PTYS_ARE_GETPT
+	if ((fd = getpt()) >= 0) {
+#  else
+	if ((fd = open("/dev/ptmx", O_RDWR)) >= 0) {
+#  endif
+	    if (grantpt(fd) == 0 	/* change slave permissions */
+		&& unlockpt(fd) == 0) {	/* slave now unlocked */
+		ptydev = ttydev = ptsname(fd);	/* get slave's name */
+		changettyowner = 0;
+		goto Found;
+	    }
+	    close(fd);
+	}
+    }
+# endif
+#endif
+#ifdef PTYS_ARE_PTC
+    if ((fd = open("/dev/ptc", O_RDWR)) >= 0) {
+	ptydev = ttydev = ttyname(fd);
+	goto Found;
+    }
+#endif
+#ifdef PTYS_ARE_CLONE
+    if ((fd = open("/dev/ptym/clone", O_RDWR)) >= 0) {
+	ptydev = ttydev = ptsname(fd);
+	goto Found;
+    }
+#endif
+#ifdef PTYS_ARE_NUMERIC
+    {
+	int             idx;
+	char           *c1, *c2;
+	char            pty_name[] = "/dev/ptyp???";
+	char            tty_name[] = "/dev/ttyp???";
+
+	ptydev = pty_name;
+	ttydev = tty_name;
+
+	c1 = &(pty_name[sizeof(pty_name) - 4]);
+	c2 = &(tty_name[sizeof(tty_name) - 4]);
+	for (idx = 0; idx < 256; idx++) {
+	    sprintf(c1, "%d", idx);
+	    sprintf(c2, "%d", idx);
+	    if (access(ttydev, F_OK) < 0) {
+		idx = 256;
+		break;
+	    }
+	    if ((fd = open(ptydev, O_RDWR)) >= 0) {
+		if (access(ttydev, R_OK | W_OK) == 0) {
+		    ttydev = strdup(tty_name);
+		    goto Found;
+		}
+		close(fd);
+	    }
+	}
+    }
+#endif
+#ifdef PTYS_ARE_SEARCHED
+    {
+	int             len;
+	const char     *c1, *c2;
+	char            pty_name[] = "/dev/pty??";
+	char            tty_name[] = "/dev/tty??";
+
+	len = sizeof(pty_name) - 3;
+	ptydev = pty_name;
+	ttydev = tty_name;
+
+# define PTYCHAR1	"pqrstuvwxyz"
+# define PTYCHAR2	"0123456789abcdef"
+	for (c1 = PTYCHAR1; *c1; c1++) {
+	    ptydev[len] = ttydev[len] = *c1;
+	    for (c2 = PTYCHAR2; *c2; c2++) {
+		ptydev[len + 1] = ttydev[len + 1] = *c2;
+	        if ((fd = open(ptydev, O_RDWR)) >= 0) {
+		    if (access(ttydev, R_OK | W_OK) == 0) {
+			ttydev = strdup(tty_name);
+			goto Found;
+		    }
+		    close(fd);
+		}
+	    }
+	}
+    }
+#endif
+
+    print_error("can't open pseudo-tty");
+    return -1;
+
+  Found:
+    fcntl(fd, F_SETFL, O_NDELAY);
+    return fd;
+}
+/*}}} */
+
+/*{{{ establish a controlling teletype for new session */
+/*
+ * On some systems this can be done with ioctl() but on others we
+ * need to re-open the slave tty.
+ */
+/* INTPROTO */
+int
+get_tty(void)
+{
+    int             fd, i;
+    pid_t           pid;
+
+/*
+ * setsid() [or setpgrp] must be before open of the terminal,
+ * otherwise there is no controlling terminal (Solaris 2.4, HP-UX 9)
+ */
+#ifndef ultrix
+# ifdef NO_SETSID
+    pid = setpgrp(0, 0);
+# else
+    pid = setsid();
+# endif
+    if (pid < 0)
+	perror("SetSID failed:");
+# ifdef DEBUG_TTYMODE
+    print_error("(%s: line %d): PID = %d\n", __FILE__, __LINE__, pid);
+# endif
+#endif				/* ultrix */
+
+    if ((fd = open(ttydev, O_RDWR)) < 0
+	&& (fd = open("/dev/tty", O_RDWR)) < 0) {
+	print_error("can't open slave tty %s", ttydev);
+	exit(EXIT_FAILURE);
+    }
+#ifdef PTYS_ARE_PTMX
+/*
+ * Push STREAMS modules:
+ *    ptem: pseudo-terminal hardware emulation module.
+ *    ldterm: standard terminal line discipline.
+ *    ttcompat: V7, 4BSD and XENIX STREAMS compatibility module.
+ */
+    if (!changettyowner) {
+	ioctl(fd, I_PUSH, "ptem");
+	ioctl(fd, I_PUSH, "ldterm");
+	ioctl(fd, I_PUSH, "ttcompat");
+    }
+#endif
+    if (changettyowner) {
+    /* change ownership of tty to real uid and real group */
+	unsigned int    mode = 0622;
+	gid_t           gid = getgid();
+
+#ifdef TTY_GID_SUPPORT
+	{
+	    struct group   *gr = getgrnam("tty");
+
+	    if (gr) {
+	    /* change ownership of tty to real uid, "tty" gid */
+		gid = gr->gr_gid;
+		mode = 0620;
+	    }
+	}
+#endif				/* TTY_GID_SUPPORT */
+#ifndef __CYGWIN32__
+	privileges(RESTORE);
+	fchown(fd, getuid(), gid);	/* fail silently */
+	fchmod(fd, mode);
+	privileges(IGNORE);
+#endif
+    }
+
+/*
+ * Close all file descriptors.  If only stdin/out/err are closed,
+ * child processes remain alive upon deletion of the window.
+ */
+    for (i = 0; i < num_fds; i++)
+	if (i != fd)
+	    close(i);
+
+/* Reopen stdin, stdout and stderr over the tty file descriptor */
+    dup2(fd, 0);		/* stdin */
+    dup2(fd, 1);		/* stdout */
+    dup2(fd, 2);		/* stderr */
+
+    if (fd > 2)
+	close(fd);
+
+#ifdef ultrix
+    if ((fd = open("/dev/tty", O_RDONLY)) >= 0) {
+	ioctl(fd, TIOCNOTTY, 0);
+	close(fd);
+    } else {
+	pid = setpgrp(0, 0);
+	if (pid < 0)
+	    perror(rs[Rs_name]);
+    }
+
+/* no error, we could run with no tty to begin with */
+#else				/* ultrix */
+# ifdef TIOCSCTTY
+    ioctl(0, TIOCSCTTY, 0);
+# endif
+
+/* set process group */
+# if defined (_POSIX_VERSION) || defined (__svr4__)
+    tcsetpgrp(0, pid);
+# elif defined (TIOCSPGRP)
+    ioctl(0, TIOCSPGRP, &pid);
+# endif
+
+/* svr4 problems: reports no tty, no job control */
+/* # if !defined (__svr4__) && defined (TIOCSPGRP) */
+    close(open(ttydev, O_RDWR, 0));
+/* # endif */
+#endif				/* ultrix */
+
+    return fd;
+}
+
+
+
+
+
+/* Previous version of get_pty and get_tty */
+#if 0
 static int
 get_pty (void)
 {
@@ -796,8 +1052,13 @@ get_tty (void)
 
    return fd;
 }
+#endif              /* End of previous version */
 /*}}}*/
 
+
+
+
+
 /*{{{ ways to deal with getting/setting termios structure */
 #ifdef HAVE_TERMIOS_H
 typedef struct termios ttymode_t;
@@ -1094,6 +1355,11 @@ int is_back_load()
   return (Options & Opt_backLoad) ? 1 : 0;
 }
 
+int is_shared_load()
+{
+  return (Options & Opt_sharedLoad) ? 1 : 0;
+}
+
 void unset_back_load()
 {
   Options&= ~Opt_backLoad;
@@ -1977,14 +2243,14 @@ cmd_getc (void)
         maxfd=xnc_set_pipes(&readfds, maxfd)+1;
         retval = select (maxfd, &readfds, NULL, NULL,
                                 (refreshed ? NULL : &value.it_value));
-        if(retval>0)
-                xnc_look_at_pipes(&readfds);
+        if(retval!=0)  //We look at pipes if got info or if got error
+	  xnc_look_at_pipes(&readfds,retval);
 
         /* See if we can read from the application */
-        if (FD_ISSET (cmd_fd, &readfds))
+        if (retval>0 && FD_ISSET (cmd_fd, &readfds))
           {
-             unsigned int count = sizeof(cmdbuf_base)-1;
-             cmdbuf_ptr = cmdbuf_endp = cmdbuf_base;
+	    unsigned int count = sizeof(cmdbuf_base)-1;
+	    cmdbuf_ptr = cmdbuf_endp = cmdbuf_base;
 
              /* while (count > sizeof(cmdbuf_base) / 2) */
              while (count)
@@ -2181,6 +2447,24 @@ process_x_event (XEvent * ev)
       break;
 
     case ButtonPress:
+      if(ev->xbutton.button==Button4)
+      {
+	if (TermWin.saveLines)
+	{
+	  scr_page (UP, TermWin.nrow * 2/5);
+	  break;
+	}
+      }
+      if(ev->xbutton.button==Button5)
+      {
+	if (TermWin.saveLines)
+	{
+	  scr_page (DN, TermWin.nrow * 2/5);
+	  break;
+	}
+      }
+
+
       bypass_keystate = (ev->xbutton.state & (Mod1Mask|ShiftMask));
       reportmode = (bypass_keystate ?
                     0 : (PrivateModes & PrivMode_mouse_report));
