@@ -58,7 +58,7 @@ extern int bool_term_on;         /*in command.c*/
 const char * rs_color [NRS_COLORS];
 Pixel PixColors [NRS_COLORS + NSHADOWCOLORS];
 
-unsigned long Options = (Opt_scrollBar) | (Opt_loginShell);
+unsigned long Options = (Opt_scrollBar) | (Opt_loginShell) | (Opt_sharedLoad);
 
 const char * display_name = NULL;
 const char * rs_name = NULL;        /* client instance (resource name) */
