@@ -17,6 +17,7 @@
 #include "down.xbm"
 #include "left.xbm"
 #include "right.xbm"
+#include "baseguiplugin.h"
 
 #define SCROLLDELAY 25
 
@@ -252,8 +253,8 @@ void   ScrollBar::init(Window ipar)
   gcw = XCreateGC(disp, w, GCBackground | GCForeground, &gcv);
   XSelectInput(disp, w, PointerMotionHintMask |
     ButtonPressMask | ExposureMask | ButtonReleaseMask | Button1MotionMask);
-  upk = new BKey(x, y - l, l, l, this, 1);
-  downk = new BKey(x, y + h + 2, l, l, this, 0);
+  upk = baseguiplugin->new_BKey(x, y - l, l, l, this, 1);
+  downk = baseguiplugin->new_BKey(x, y + h + 2, l, l, this, 0);
   upk->init(parent);
   downk->init(parent);
   upk->setpixmap(pup, 15, 15);
