@@ -4,6 +4,7 @@
 #include "globals.h"
 #include "flist.h"
 #include "au/au_sup.h"
+#include "ftpcfg.h"
 #include "ftplib/ftp_communication.h"
 
 //Virtual file system types.
@@ -26,6 +27,32 @@
 #define PROMPT_DEL         (1<<3)        /*Prompt for delete operation*/
 #define PROMPT_OVR         (1<<4)        /*Prompt for overwrite existing files*/
 
+//File operations than can be called via Lister::funcs(ManFuncs)
+enum ManFuncs { 
+  FDELETE    =  0,
+  FCOPY      =  1,
+  FMOVE      =  2,
+  FMKDIR     =  3,
+  FEDIT      =  4,
+  FSELBYMASK =  5,
+  FDESELMASK =  6,
+  FSETATTR   =  7,
+  FLPR       =  8,
+  FWIDEEXEC  = 10,
+  FMANPAGE   = 11,
+  FFTPCON    = 12,
+  FFTPCONPWD = 13,
+  FCHOWN     = 20,
+  FMOUNT     = 22
+};
+
+struct VFS_Info
+{
+  int      vfstype;
+  char     full_path[L_MAXPATH];
+  char     filename[L_MAXPATH];
+};
+
 class VFS   //Base Virtual File System class
 {
  public:
@@ -124,7 +151,8 @@ class VFS   //Base Virtual File System class
   virtual int   full_extract_to_vfs(VFS* vfs)          //Make full extraction to vfs
                      {return 255;};
   virtual int   make_fullpath() {return -1;};          //Make full pathname from local one
-  virtual int   init_support(char*) {return 0;};       //init vfs support files if needed
+  virtual int   init_support(char *dir,char subdir=0) 
+                     {return 0;};                      //init vfs support files if needed
   virtual void* new_alloc(int size)                    //allocate memory for any
   {
           int si=VFS_MEM_BLOCK;
@@ -164,6 +192,8 @@ public:
    int dup_entry;
    int ls_timeout;
    int transfer_cache_timeout; 
+   FTPCFG_S  ftpcfg;  
+
    FTP() : VFS(FTP_TYPE, "FTP") 
         { int i; char *ptr=(char*) &com;
           work=0; bgbit=0;autoraise=0;dup_entry=-1;options=0;
@@ -173,7 +203,7 @@ public:
               ptr[i]=0;
         };
    void          op_complete() {work=0;};
-   virtual int   init_support(char *);
+   virtual int   init_support(char* dir, char *subdir=0);
    void          do_work();
    virtual void  close_fs();
    virtual int   direc(char*);
@@ -209,7 +239,7 @@ public:
    void          child_ftp_command();
    void          make_empty_list();
    void          bg_select();
-   void          bg_select_if_set(fd_set*);
+   void          bg_select_if_set(fd_set*,int ret);
    int           bg_fd_set(int, fd_set*);
    void          bg_commands();
    void          bg_switch();
@@ -274,7 +304,7 @@ public:
   virtual int   is_del_supported();
   virtual int   copy(FList* cur,VFS*);
   virtual int   remove(FList* cur);
-  virtual int   init_support(char*);
+  virtual int   init_support(char *dir, char *subdir=0);
   void          convert_attributes(int& mode,int, char *at, char *name);
   int           reread();
   int           get_sublevel(char *file,int mode);
@@ -333,7 +363,7 @@ public:
      return ::chdir(curdir);
   };
 
-  virtual int   init_support(char*) 
+  virtual int   init_support(char *dir, char *subdir=0) 
   {     
     for(int i=0;i<VFS_MAX_MEM;i++)
       lar[i]=NULL;
@@ -388,3 +418,5 @@ extern VFS   *define_vfs(char *d);
 extern int    afstmp_defined;
 
 #endif
+/* ------------ End of file -------------- */
+
