@@ -57,15 +57,23 @@ void str2version(char *str,int *ver)
 
 int create_file(char *path, char *fname, char *buf, int siz)
 {
-        char str[2048];
-        int fp;
-        sprintf(str,"%s/%s",path,fname);
-        fp=open(str,O_WRONLY | O_CREAT,0600);
-        if(fp==-1)
-	  return 0;
-        write(fp,buf,siz);
-        close(fp);
-        return 1;
+  char str[2048];
+  int fp;
+  xncdprintf(("create_file(%x,%x,%x,%d) called\n",path,fname,buf,siz));
+  xncdprintf(("create_file: path=[%s], fname=[%s], size=%d\n",path,fname,siz));
+  sprintf(str,"%s/%s",path,fname);
+  fp=open(str,O_WRONLY | O_CREAT | O_TRUNC,0600);
+  if(fp==-1)
+  {
+    xncdprintf(("create_file: creating failed for [%s]\n",str));
+    xncdprintf(("create_file: reason is %s",strerror(errno)));
+    return 0;
+  }
+  xncdprintf(("create_file: writing data\n"));
+  write(fp,buf,siz);
+  close(fp);
+  xncdprintf(("create_file: [%s] created ok\n",str));
+  return 1;
 }
 
 int is_new_version()
@@ -489,7 +497,7 @@ X_PAR  resources[] =
   "xnc.afs.update", "Xnc.AFS.Update", updatechr
 };
 
-int    resn = sizeof(resources) / sizeof(X_PAR);
+const int resn = 16; //sizeof(resources) / sizeof(X_PAR);
 
 X_PAR  colors[] =
 {
@@ -507,7 +515,7 @@ X_PAR  colors[] =
   "leoprogs.afs.color", "LeoProgs.AFS.Color", bgchr11
 };
 
-int    coln = sizeof(colors) / sizeof(X_PAR);
+const int    coln = 12;  //sizeof(colors) / sizeof(X_PAR);
 
 unsigned long keyscol[3];
 unsigned long cols[12];
@@ -736,23 +744,35 @@ void   InitXClient(int argc, char **argv, int wx, int wy, int wl, int wh, char
   fprintf(stderr, "Loading resources....");
   strcpy(rfile, home_files_dir);
   strcat(rfile, "/xnc.ini");
+  xncdprintf(("Main resource file [%s], plugin handle - %x\n",rfile,guiplugin));
   strcpy(plugin_rfile, home_files_dir);
   strcat(plugin_rfile, guiplugin->get_ini_filename());
+  xncdprintf(("Plugin resource file [%s]\n",plugin_rfile));
   plugin_rdb = XrmGetFileDatabase(plugin_rfile);
   rdb = XrmGetFileDatabase(rfile);
 
+  xncdprintf(("Plugin_db [%x], Main_db [%x]\n",plugin_rdb,rdb));
+
   if(rdb && plugin_rdb)
+  {
+    xncdprintf(("Merging resources\n"));
     XrmMergeDatabases(plugin_rdb,&rdb);
+  }
 
   if (rdb != NULL)
+  {
+    xncdprintf(("Reading resources\n"));
     for (i = 0; i < resn; i++)
       {
         fprintf(stderr, ".");
+	xncdprintf(("GettingResource: [%s][%s]\n",resources[i].name, resources[i].cname));
         if (XrmGetResource(rdb, resources[i].name, resources[i].cname, &rmt, &rmv))
           strcpy(resources[i].pstr,rmv.addr);
         else
-          fprintf(stderr, "%s: Error getting resource: %s\n", argv[0], resources[i].name);
+          fprintf(stderr, "%s: Error getting resource: %s\n", argv[0], 
+		  resources[i].name);
       }
+  }
   else
     fprintf(stderr, "!!!XNC PANIC!!!: Can't open resource file [%s].\n", rfile);
   strcpy(l_bg_string, resources[2].pstr);
@@ -1090,6 +1110,19 @@ char  *getseq(char *str, char *w, int nocase = 1)
   return str;
 }
 
+char  *getrest(char *str,char *w, int nocase = 1)
+{
+  while(*str==' ')
+    str++;
+  while(*str && *str!='\n' && *str!='\r')
+    if(nocase)
+      *w++ = tolower(*str++);
+    else
+      *w++=*str++;
+  *w=0;
+  return str;
+}
+
 int    load_config(char *fname, Lister * l1, Lister * l2)
 {
   char   str[200], *s=XNCVERSION;
@@ -1101,6 +1134,7 @@ int    load_config(char *fname, Lister * l1, Lister * l2)
     return 0;
   while (fgets(str, 200, fp) != NULL)
     {
+      xncdprintf(("Config read: %s",str));
       if (str[0] != '#')
         {
           s = getseq(str, w);
@@ -1226,47 +1260,47 @@ int    load_config(char *fname, Lister * l1, Lister * l2)
                   break;
                 case 9:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(0, w, j);
                   break;
                 case 10:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(1, w, j);
                   break;
                 case 11:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(2, w, j);
                   break;
                 case 12:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(3, w, j);
                   break;
                 case 13:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(4, w, j);
                   break;
                 case 14:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(5, w, j);
                   break;
                 case 15:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(6, w, j);
                   break;
                 case 16:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(7, w, j);
                   break;
                 case 17:
                   j = detect_fs(w);
-                  getseq(s, w, 0);
+                  getrest(s+1, w, 0);
                   bmark->add_book(8, w, j);
                   break;
                 case 18:
