@@ -1331,7 +1331,7 @@ void load(char *rfile)
 }          
  
 char tmpstr[100];
-void main(int argc,char** argv)
+int main(int argc,char** argv)
 {
  char *name="X Northern Captain Setup";
  int i,nf,fp11,lfl;
@@ -1588,6 +1588,7 @@ void main(int argc,char** argv)
  fprintf(stderr,"OK\n");
  DeinitXClient();
  }
+ return 0;
 }
 
         
